##############################################################################
#
# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Backward-compatibility imports for the global principal registry directives

$Id: metadirectives.py 106799 2009-12-20 04:50:49Z fafhrd $
"""

# BBB: these were moved to zope.principalregistry
from zope.principalregistry.metadirectives import (
        IBasePrincipalDirective,
        IDefinePrincipalDirective,
        IDefineUnauthenticatedPrincipalDirective,
        IDefineUnauthenticatedGroupDirective,
        IDefineAuthenticatedGroupDirective,
        IDefineEverybodyGroupDirective,
    )
